==> lokalise_flutter_sdk-0.5.0.tar.gz: lib/otav2/data/repositories/remote_bundle_repository.dart <==
import 'dart:convert';
import 'package:archive/archive_io.dart';
import 'package:path/path.dart' as path;
import 'package:lokalise_flutter_sdk/otav2/data/api/ota_api.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/requests/bundle_request.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/dto/get_remote_bundle_dto.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/exceptions/internal_exception.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/bundle.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/language_bundle.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/translation/translation.dart';
import 'package:lokalise_flutter_sdk/otav2/helpers/message_parser_wrapper.dart';

class RemoteBundleRepository {
  final OtaApi _otaApi;

  RemoteBundleRepository({required OtaApi otaApi}) : _otaApi = otaApi;

  Future<Bundle> getBundle({
    required GetRemoteBundleDto getRemoteBundleDto,
  }) async {
    final request = BundleRequest(
      translationVersion: getRemoteBundleDto.translationVersion,
      appVersion: getRemoteBundleDto.appVersion,
      preRelease: getRemoteBundleDto.preRelease,
    );
    final response = await _otaApi.getBundle(
      credentials: getRemoteBundleDto.credentials,
      request: request,
    );

    // The response can be null if we already have the latest bundle cached.
    if (response == null) {
      return Bundle(
        projectId: getRemoteBundleDto.credentials.projectId,
        translationVersion: getRemoteBundleDto.translationVersion,
        appVersion: getRemoteBundleDto.appVersion,
        languageBundles: [],
      );
    }

    return Bundle(
      projectId: getRemoteBundleDto.credentials.projectId,
      translationVersion: response.version,
      appVersion: getRemoteBundleDto.appVersion,
      languageBundles: _extractArchive(response.bundle),
    );
  }

  List<LanguageBundle> _extractArchive(Archive archive) {
    if (archive.isEmpty) {
      throw InternalException.bundleEmpty();
    }

    List<LanguageBundle> result = [];
    try {
      // The first element in the folder (locale/) so we skip it.
      for (ArchiveFile file in archive.files.skip(1)) {
        // Getting and validating the locale from file name
        // 'locale/es_AR.json' = 'es_AR'
        final locale = _getLocaleFromFileName(file.name);

        final Map<String, dynamic> content = json.decode(
          utf8.decode(file.content),
        );

        // Transformin Map<String, String> into Map<String, Translation?>
        final translations = content.map(
          (key, value) => MapEntry(
            key,
            MessageParserWrapper(text: value.toString()).translation,
          ),
        );
        // Removing entries with a null value
        translations.removeWhere((_, value) => value == null);

        result.add(
          LanguageBundle(
            locale: locale,
            translations:
                Map.castFrom<String, Translation?, String, Translation>(
              translations,
            ),
          ),
        );
      }
    } catch (_) {
      throw InternalException.bundleFormat(param: archive);
    }

    return result;
  }

  String _getLocaleFromFileName(String fileName) {
    final locale = path.basenameWithoutExtension(fileName);

    if (locale.length == 2) {
      return locale;
    }

    if (locale.length == 5) {
      final parts = locale.split('_');
      if (parts.length == 2 && parts[0].length == 2 && parts[1].length == 2) {
        return locale;
      }
    }

    // Will be transformed into InternalException.bundleFormat on
    // the above method.
    throw Exception();
  }
}

==> lokalise_flutter_sdk-0.5.1.tar.gz: lib/otav2/data/repositories/remote_bundle_repository.dart <==
import 'dart:convert';
import 'package:archive/archive_io.dart';
import 'package:path/path.dart' as path;
import 'package:lokalise_flutter_sdk/otav2/data/api/ota_api.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/requests/bundle_request.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/dto/get_remote_bundle_dto.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/exceptions/internal_exception.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/bundle.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/language_bundle.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/translation/translation.dart';
import 'package:lokalise_flutter_sdk/otav2/helpers/message_parser_wrapper.dart';

class RemoteBundleRepository {
  final OtaApi _otaApi;

  RemoteBundleRepository({required OtaApi otaApi}) : _otaApi = otaApi;

  Future<Bundle?> getBundle({
    required GetRemoteBundleDto getRemoteBundleDto,
  }) async {
    final request = BundleRequest(
      translationVersion: getRemoteBundleDto.translationVersion,
      appVersion: getRemoteBundleDto.appVersion,
      preRelease: getRemoteBundleDto.preRelease,
    );
    final response = await _otaApi.getBundle(
      credentials: getRemoteBundleDto.credentials,
      request: request,
    );

    // response can be null if we already have the latest bundle cached.
    if (response == null) {
      return null;
    }

    return Bundle(
      projectId: getRemoteBundleDto.credentials.projectId,
      translationVersion: response.version,
      appVersion: getRemoteBundleDto.appVersion,
      languageBundles: _extractArchive(response.bundle),
    );
  }

  List<LanguageBundle> _extractArchive(Archive archive) {
    if (archive.isEmpty) {
      throw InternalException.bundleEmpty();
    }

    List<LanguageBundle> result = [];
    try {
      // The first element is the folder (locale/) so we skip it.
      for (ArchiveFile file in archive.files.skip(1)) {
        // Getting and validating the locale from file name
        // 'locale/es_AR.json' = 'es_AR'
        final locale = _getLocaleFromFileName(file.name);

        final Map<String, dynamic> content = json.decode(
          utf8.decode(file.content),
        );

        // Transformin Map<String, String> into Map<String, Translation?>
        final translations = content.map(
          (key, value) => MapEntry(
            key,
            MessageParserWrapper(text: value.toString()).translation,
          ),
        );
        // Removing entries with a null value
        translations.removeWhere((_, value) => value == null);

        result.add(
          LanguageBundle(
            locale: locale,
            translations:
                Map.castFrom<String, Translation?, String, Translation>(
              translations,
            ),
          ),
        );
      }
    } catch (_) {
      throw InternalException.bundleFormat(param: archive);
    }

    return result;
  }

  String _getLocaleFromFileName(String fileName) {
    final locale = path.basenameWithoutExtension(fileName);

    if (locale.length == 2) {
      return locale;
    }

    if (locale.length == 5) {
      final parts = locale.split('_');
      if (parts.length == 2 && parts[0].length == 2 && parts[1].length == 2) {
        return locale;
      }
    }

    // Will be transformed into InternalException.bundleFormat on
    // the above method.
    throw Exception();
  }
}
